/* event table functions, called from event library in response to
	events
	
	93/10/18 aih - created */

#include "EventLib.h"
#include "ListLib.h"

static EventTableType gEventTable;
	
static void keydown(EventObjectType object, EventRecord *event)
{
	ListKeyDown(object, event);
}

static Boolean menu(EventObjectType object, const MenuPickType *pick)
{
	ListMenu(object, pick);
}

static void adjustmenu(EventObjectType object)
{
	ListAdjustMenu(object);
}

static Boolean within(EventObjectType object, Point where)
{
	return ListWithin(object, where);
}

static Boolean mousedown(EventObjectType object, EventRecord *event)
{
	FocusSet(object);
	ListMouseDown(object, event);
	return(true);
}

static void zoom(EventObjectType object, short *width, short *height)
{
	ListZoom(object, width, height);
}

static void resize(EventObjectType object, short dh, short dv)
{
	ListResize(object, dh, dv);
}

static void update(EventObjectType object)
{
	ListUpdate(object);
}

static void focus(EventObjectType object, Boolean focus)
{
	ListFocus(object, focus);
}

static void activate(EventObjectType object, Boolean activate)
{
	ListActivate(object, activate);
}

const /* EventTableType */ void *ListEventTable(void)
{
	return(&gEventTable);
}

void ListEventTableRegister(void)
{
	gEventTable.focusObject.keydown = keydown;
	gEventTable.focusObject.menu = menu;
	gEventTable.focusObject.adjustmenu = adjustmenu;
	gEventTable.focusWindow.within = within;
	gEventTable.focusWindow.mousedown = mousedown;
	gEventTable.focusWindow.focus = focus;
	gEventTable.window.zoom = zoom;
	gEventTable.window.resize = resize;
	gEventTable.window.update = update;
	gEventTable.window.activate = activate;
	EventTableRegister(&gEventTable);
}
