#pragma once

#include "ControlLib.h"
#include "WindowLib.h"

#define DLG_PRELOAD_MAX (4) /* maximum number of preloaded dialogs */

/* data validation (usually used only in assertions) */
Boolean DlgValid(DialogPtr dlg);
Boolean DlgExtraValid(DialogPtr dlg);
Boolean DlgItemValid(DialogPtr dlg, short item);

/* accessing dialog items */
short DlgNItems(DialogPtr dlg);
short DlgType(DialogPtr dlg, short item);
void DlgTypeSet(DialogPtr dlg, short item, short type);
Handle DlgHandle(DialogPtr dlg, short item);
void DlgHandleSet(DialogPtr dlg, short item, Handle hndl);
void DlgBox(DialogPtr dlg, short item, Rect *box);
void DlgBoxSet(DialogPtr dlg, short item, Rect *box);

/* text field */
void DlgText(DialogPtr dlg, short item, CStr255 str);
void DlgTextLen(DialogPtr dlg, short item, char *str, short len);
void DlgTextSet(DialogPtr dlg, short item, const CStr255 str);
void DlgTextSelect(DialogPtr dlg, short item, short start, short end);
void DlgTextSelectAll(DialogPtr dlg, short item);
long DlgNum(DialogPtr dlg, short item);
void DlgNumSet(DialogPtr dlg, short item, long num);
float DlgFloat(DialogPtr dlg, short item);
void DlgFloatSet(DialogPtr dlg, short item, float num, short precision);

/* default item */
short DlgDefault(DialogPtr dlg);
void DlgDefaultSet(DialogPtr dlg, short item);
void DlgDefaultFrame(DialogPtr dlg, Pattern pat);

/* clicked item */
void DlgClick(DialogPtr dlg, short item);
short DlgClicked(DialogPtr dlg);

/* positioning dialogs */
void DlgCenter(DialogPtr dlg);
void DlgPosition(DialogPtr dlg);
void DlgPositionPoint(short id, Point *pt);

/* creating and disposing of dialogs */
DialogPtr DlgBeginAlert(short id);
DialogPtr DlgBegin(short id);
void DlgEnd(DialogPtr dlg);

/* preloading dialogs */
DialogPtr DlgPreload(ResType type, short id);
void DlgUnload(ResType type, short id);

/* event registering */
void DlgETRegister(void);

/* Macros for determining the type of a dialog item. The 't' parameter should
	be the type of an item (as returned by DlgType). */
#define DlgTypeCtl(t)			((((t) & 0x3F) & ctrlItem) != 0)
#define DlgTypeBtnCtl(t)		(((t) & 0x3F) == ctrlItem)
#define DlgTypeChkCtl(t)		(((t) & 0x3F) == ctrlItem + chkCtrl)
#define DlgTypeRadCtl(t)		(((t) & 0x3F) == ctrlItem + radCtrl)
#define DlgTypeResCtl(t)		(((t) & 0x3F) == ctrlItem + resCtrl)
#define DlgTypeIconItem(t)		(((t) & 0x3F) == iconItem)
#define DlgTypePicItem(t)		(((t) & 0x3F) == picItem)
#define DlgTypeUserItem(t)		(((t) & 0x3F) == userItem)
#define DlgTypeStatText(t)		(((t) & 0x3F) == statText)
#define DlgTypeEditText(t)		(((t) & 0x3F) == editText)
#define DlgTypeText(t)			((((t) & 0x3F) & (statText | editText)) != 0)
#define DlgTypeDisabled(t)		(((t) & itemDisable) != 0)
#define DlgTypeEnabled(t)		(! DlgTypeDisabled(t))

/* macros for control items */
#define DlgCtl(dlg, item)							((ControlHandle) DlgHandle(dlg, item))
#define DlgCtlValue(dlg, item)					CtlValue(DlgCtl(dlg, item))
#define DlgCtlValueSet(dlg, item, value)		CtlValueSet(DlgCtl(dlg, item), value)
#define DlgCtlMin(dlg, item)						GetCtlMin(DlgCtl(dlg, item))
#define DlgCtlMinSet(dlg, item, value)			SetCtlMin(DlgCtl(dlg, item), value)
#define DlgCtlMax(dlg, item)						GetCtlMax(DlgCtl(dlg, item))
#define DlgCtlMaxSet(dlg, item, value)			SetCtlMax(DlgCtl(dlg, item), value)
#define DlgCtlRefCon(dlg, item)					GetCRefCon(DlgCtl(dlg, item))
#define DlgCtlRefConSet(dlg, item, value)		SetCRefCon(DlgCtl(dlg, item), value)
#define DlgCtlEnabled(dlg, item)					CtlEnabled(DlgCtl(dlg, item))
#define DlgCtlEnableSet(dlg, item, enable)	CtlEnableSet(DlgCtl(dlg, item), enable)
#define DlgCtlTitle(dlg, item, title)			CtlTitle(DlgCtl(dlg, item), title)
#define DlgCtlTitleSet(dlg, item, title)		CtlTitleSet(DlgCtl(dlg, item), title)
#define DlgFlashButton(dlg, item)				CtlFlashButton(DlgCtl(dlg, item))
