#pragma once

#include <limits.h>
#include <time.h>
#include "LLPtrLib.h"

/* The minimum size of the hash table is determined by the size of the
	alphabet used to calculate the hash key value. In this implementation,
	the alphabet is made up of characters. The size of the hash table
	must be larger than and relatively prime to the minimum size. */
#define HASH_MINSIZE (UCHAR_MAX + 1)

typedef struct {
	size_t size;		/* size of hash table */
	size_t nitems;		/* number of items in table */
	LLPtr *table;		/* the hash table (an array of linked lists) */
} HashType, *HashPtr, **HashHandle;

typedef int (*HashCompareType)(const void *key, const LLPtr item);
typedef int (*HashSortType)(const void *item1, const void *item2);
typedef void (*HashDisposeType)(void *item);

Boolean HashValid(HashPtr hash);

HashPtr HashBegin(size_t size);
void HashEnd(HashPtr hash, HashDisposeType dispose);

size_t HashSize(HashPtr hash);
size_t HashNItems(HashPtr hash);
size_t HashCalculateSize(size_t minsize, clock_t maxtime);
size_t HashIndex(HashPtr hash, const void *key, size_t n);

LLPtr HashEntry(HashPtr hash, size_t index);
LLPtr HashFind(HashPtr hash, const void *key, size_t index,
	HashCompareType compare);
void HashInsert(HashPtr hash, LLPtr item, size_t index);
void HashDelete(HashPtr hash, LLPtr item, size_t index);
LLPtr *HashSort(HashPtr hash, HashSortType compare);
HashPtr HashRehash(HashPtr hash, size_t size);
