#pragma once

#include <PrintTraps.h>
#include "FileLib.h"
#include "LLHandleLib.h"
#include "MenuLib.h"

#define DOC_VERSION		(1)	/* version of this library */
#define DOC_ALL_TYPES	(0)	/* value of gDocNTypes that allows opening all file types */

/* resources stored with the document */
#define DOC_WPOS			(128)	/* window position */
#define DOC_PRNT			(128)	/* printer record */

typedef struct DocumentStruct DocumentType, *DocumentPtr, **DocumentHandle;

typedef struct {
	void (*begin)(DocumentHandle doc);
	void (*end)(DocumentHandle doc);
	void (*read)(DocumentHandle doc, FileType *fp, Boolean *untitled);
	void (*write)(DocumentHandle doc, FileType *fp);
	Boolean (*dirty)(DocumentHandle doc);
	struct {
		void *(*begin)(DocumentHandle doc, THPrint print, TPPrPort port,
			const Rect *pageRect, short firstPage, short lastPage);
		void (*end)(DocumentHandle doc, void *data);
		Boolean (*page)(DocumentHandle doc, void *data);
		short (*npages)(DocumentHandle doc, void *data);
	} print;
} DocumentTableType, *DocumentTablePtr, **DocumentTableHandle;

typedef struct DocumentStruct {
	LLType		next;		/* next document */
	WindowPtr	window;	/* window containing document */
	OSType		type;		/* type of files saved by document */
	OSType		creator;	/* creator of files saved by document */
	THPrint		print;	/* printer record */
	Boolean		autosave;/* true enables automatic saving of document on close */
	Boolean		dirty;	/* true if modified since last save */
	Boolean		hasfile;	/* true if associated with a file (not untitled) */
	FileType		*fp;		/* file associated with document */
	void			*data;	/* application defined data */
	const DocumentTableType *table;	/* handler functions */
};

/* If this is set to true then printing doesn't go to the printer, instead the
	current window is used as the printer. You will see each page displayed
	in the window, which can save a lot of paper. */
extern Boolean gDocPrintTest;

/* validation */
Boolean DocValid(DocumentHandle doc);

/* allocation */
DocumentHandle DocBegin(FileType *fp);
void DocEnd(DocumentHandle doc);

/* active document */
DocumentHandle DocActive(void);

/* attributes */
void *DocData(DocumentHandle doc);
void DocDataSet(DocumentHandle doc, void *data);
WindowPtr DocWindow(DocumentHandle doc);
void DocName(DocumentHandle doc, CStr255 name);
Boolean DocDirty(DocumentHandle doc);
void DocDirtySet(DocumentHandle doc, Boolean dirty);
Boolean DocHasFile(DocumentHandle doc);
FileType *DocFile(DocumentHandle doc);
void DocFileSet(DocumentHandle doc, FileType *fp);
OSType DocCreator(DocumentHandle doc);
void DocCreatorSet(DocumentHandle doc, OSType creator);
OSType DocType(DocumentHandle doc);
void DocTypeSet(DocumentHandle doc, OSType type);
THPrint DocPrintRecord(DocumentHandle doc);
Boolean DocAutoSave(DocumentHandle doc);
void DocAutoSaveSet(DocumentHandle doc, Boolean autosave);
const DocumentTableType *DocTable(DocumentHandle doc);
void DocTableSet(DocumentHandle doc, const DocumentTableType *table);

/* file IO */
void DocRead(DocumentHandle doc, FileType *fp);
void DocWrite(DocumentHandle doc, FileType *fp);

/* printing */
void DocPrintWithRecord(DocumentHandle doc, THPrint print);

/* file menu operations */
void DocNew(void);
void DocOpen(void);
void DocClose(DocumentHandle doc, short prompt);
void DocSave(DocumentHandle doc);
void DocSaveAs(DocumentHandle doc);
void DocRevert(DocumentHandle doc);
void DocPageSetup(DocumentHandle doc);
void DocPrint(DocumentHandle doc);
void DocQuit(void);

/* menu handling */
Boolean DocMenu(const MenuPickType *pick);
void DocAdjustMenu(void);

/* low memory */
void DocMemoryLow(void);

/* event table */
const /* EventTableType */ void *DocEventTable(void);
void DocEventTableRegister(void);

/* handler table */
void DocTableRegister(const DocumentTableType *table, short ntypes,
	const OSType *types);

/* high-level events */
void DocHLEInstall(void);
