/* Do buffered io, which is more efficient for small reads (e.g., one
	character at a time) than using the file manager or the simpler
	FileRead... functions.

	93/10/25 aih - created
*/

#include <string.h>
#include "FileBufferLib.h"

/* initialize the buffer */
void FBufInit(FileBufferType *buf, FileType *fp)
{
	memclr(buf, sizeof(FileBufferType));
	buf->fp = fp;
}

/* true if at eof in file */
Boolean (FBufEof)(FileBufferType *buf)
{
	return(buf->eof);
}

/* seek to position in file */
void FBufSeek(FileBufferType *buf, size_t pos)
{
	FileSeek(buf->fp, fsFromStart, pos);
	buf->index = buf->size = 0;
	buf->position = pos;
}

/* read a character from the file; the file is buffered so reads are
	more efficient */
char _FBufReadChar(FileBufferType *buf)
{
	if (buf->index == buf->size) {
		buf->size = FileRead(buf->fp, FILE_BUFSIZ, buf->data);
		buf->position += buf->size;
		buf->index = 0;
		if (buf->size == 0)
			buf->eof = true;
	}
	return(! buf->eof ? buf->data[buf->index++] : 0);
}

/* push the character back onto the buffered file */
void FBufUnreadChar(FileBufferType *buf)
{
	if (buf->index > 0)
		--buf->index;
	else if (buf->position > buf->size + 1)
		FBufSeek(buf, buf->position - buf->size - 1);
	buf->eof = false;
}
