#pragma once

#define FRAME_WIDTH				(1)		/* width of border */
#define FRAME_FOCUS_MARGIN		(1)		/* margin to list input focus border */
#define FRAME_FOCUS_WIDTH		(2)		/* width of list input focus border */
#define FRAME_FOCUS_SIZE		(3)		/* FRAME_FOCUS_MARGIN + FRAME_FOCUS_WIDTH */

#define FRAME_VISIBLE			(1<<0)	/* set if frame is visible */
#define FRAME_ACTIVE				(1<<1)	/* set if frame is active */
#define FRAME_FOCUS				(1<<2)	/* set if frame has input focus */
#define FRAME_ANCHOR_RIGHT		(1<<3)	/* set if right edge adjusted on resize */
#define FRAME_ANCHOR_BOTTOM	(1<<4)	/* set if bottom edge adjusted on resize */
#define FRAME_KEEP_ACTIVE		(1<<5)	/* set if always active */
#define FRAME_KEEP_INACTIVE	(1<<6)	/* set if never active */
#define FRAME_HSCROLL			(1<<7)	/* set if has horizontal scroll bar */
#define FRAME_VSCROLL			(1<<8)	/* set if has vertical scroll bar */
#define FRAME_LIST				(1<<9)	/* set if needs list input focus border */

typedef short FrameFlagsType;

typedef struct {
	WindowPtr	window;	/* window containing frame */
	Rect			bounds;	/* frame's bounding rectangle */
	short			cursor;	/* id of cursor to display when mouse is in frame */
	short			margin;	/* margin between content rectangle to border */
	FrameFlagsType	flags;/* various flags */
} FrameType, *FramePtr, **FrameHandle;

Boolean FrameValid(FrameHandle frame);
FrameHandle FrameBegin(WindowPtr window, const Rect *bounds, short margin);
void FrameEnd(FrameHandle frame);
FrameFlagsType FrameFlags(FrameHandle frame);
void FrameFlagsSet(FrameHandle frame, FrameFlagsType flags);
Boolean FrameFlagTest(FrameHandle frame, FrameFlagsType flags);
void FrameFlagSet(FrameHandle frame, FrameFlagsType flags, Boolean set);
void FrameActivate(FrameHandle frame, Boolean active);
void FrameFocus(FrameHandle frame, Boolean focus);
Boolean FrameHilite(FrameHandle frame);
void FrameCursor(FrameHandle frame, short cursor);
void FrameContent(FrameHandle frame, Rect *content);
void FrameBounds(FrameHandle frame, Rect *bounds);
short FrameMinWidth(FrameHandle frame);
short FrameMinHeight(FrameHandle frame);
Boolean FrameWithin(FrameHandle frame, Point where);
void FrameDraw(FrameHandle frame);
void FrameGrow(FrameHandle frame, Rect *size);
void FrameZoom(FrameHandle frame, short *width, short *height);
void FrameResize(FrameHandle frame, short dh, short dv);
Boolean FrameAdjustCursor(FrameHandle frame, Point where, RgnHandle cursor);
const /* EventTableType */ void *FrameEventTable(void);
void FrameEventTableRegister(void);
