#pragma once

#include <stddef.h>

#define MEM_CLEAR	(0x00)	/* fill memory on allocation */
#define MEM_JUNK	(0xff)	/* fill memory before disposal */
#define MEM_HDRSZ	(12)		/* approximate size of a block header */

/* low memory warnings */
typedef enum {
	MEM_WARNING_NONE,			/* no memory shortage */
	MEM_WARNING_LOW,			/* first warning to user to close windows */
	MEM_WARNING_VERY_LOW,	/* ask user to close each window, disable
										some features until enough memory */
	MEM_WARNING_CRITICAL,	/* disable features until enough memory */
	MEM_WARNING_FATAL,		/* about to die */
	MEM_WARNING_LAST
} MemoryWarningType;

/* verifying any pointer */
Boolean MemValid(const void *p);

/* memory reserves and warnings */
void MemInit(size_t cushion, size_t reserve);
MemoryWarningType MemWarning(void);
Boolean MemAvailable(size_t n);
Boolean MemAvailableNoCushion(size_t n);
Boolean MemCanFail(Boolean canfail);
void MemCheck(size_t n);

/* operations on handles */
Boolean HandleValid(void *h);
Boolean HandleValidSize(void *h, size_t n);
SignedByte HandleState(void *h);
Boolean HandleIsResource(void *h);
Boolean HandleIsLocked(void *h);
Boolean HandleIsPurgeable(void *h);
SignedByte HandleNoPurge(void *h);
SignedByte HandleLock(void *h);
SignedByte HandleLockHi(void *h);
void HandleRestore(void *h, SignedByte state);
void HandleUnlock(void *h);
void HandlePurge(void *h);
size_t HandleSize(void *h);
void HandleSizeSet(void *h, size_t n);
void HandleReallocate(void *h, size_t n);
void HandleEmpty(void *h);
void *HandleCopy(void *src);
void *HandleBegin(size_t n);
void *HandleBeginClear(size_t n);
void HandleEnd(void *h);

/* operations on pointers */
Boolean PtrValid(void *p);
Boolean PtrValidSize(void *p, size_t n);
size_t PtrSize(void *p);
void PtrSizeSet(void *p, size_t n);
void *PtrToHandle(void *p);
void *PtrBegin(size_t n);
void *PtrBeginClear(size_t n);
void PtrEnd(void *p);

/* operations on regions */
Boolean ValidateRgn(RgnHandle rgn);
RgnHandle BeginRgn(void);
void EndRgn(RgnHandle rgn);

/* heap and stack information */
size_t MemStackSize(void);
size_t MemHeapSize(void);
size_t MemContiguousSize(void);
