#pragma once

/* menu commands */
typedef enum {

	CMD_NONE,

	CMD_APPLE,
	CMD_ABOUT,
	CMD_HELP,

	CMD_FILE,
	CMD_NEW,
	CMD_OPEN,
	CMD_CLOSE,
	CMD_SAVE,
	CMD_SAVE_AS,
	CMD_REVERT,
	CMD_PAGE_SETUP,
	CMD_PRINT,
	CMD_QUIT,

	CMD_EDIT,
	CMD_UNDO,
	CMD_CUT,
	CMD_COPY,
	CMD_PASTE,
	CMD_CLEAR,
	CMD_SELECT_ALL,
	CMD_CLIPBOARD,
	CMD_PREFERENCES,
	
	CMD_FONT,
	CMD_SIZE,
	CMD_STYLE,

	CMD_JUST,
	CMD_JUSTIFY_LEFT,
	CMD_JUSTIFY_RIGHT,
	CMD_JUSTIFY_CENTER,

	CMD_TEXT,
	CMD_MARGIN,

	CMD_WINDOW,

	CMD_DEBUG,
	CMD_DEBUG_DEBUGGER,
	CMD_DEBUG_WINDOW,
	CMD_DEBUG_MEMORY,
	CMD_DEBUG_ASSERT_ALL,
	CMD_DEBUG_ASSERT_REQUIRE,
	CMD_DEBUG_ASSERT_ENSURE,
	CMD_DEBUG_ASSERT_CHECK,
	CMD_DEBUG_ASSERT_BREAK,
	CMD_DEBUG_ASSERT_RAISE,
	CMD_DEBUG_ASSERT_TRACE,
	CMD_DEBUG_ASSERT_STACK,
	CMD_DEBUG_CONSOLE,
	CMD_DEBUG_PROFILE,
	CMD_DEBUG_TRACE,

	CMD_LAST
} MenuCommandType;

typedef struct {
	short id;
	short item;
	MenuCommandType cmd;
	MenuHandle menu;
} MenuPickType;

/* validation */
Boolean MenuValid(MenuHandle menu);
Boolean MenuIDValid(short id);
Boolean MenuItemValid(short id, short item);
Boolean MenuCmdValid(MenuCommandType cmd);
Boolean MenuPickValid(const MenuPickType *pick);

/* menu table */
void MenuTableSet(const MenuPickType *mt);
void MenuTableAppend(const MenuPickType *mt);

/* menu commands */
MenuPickType MenuPick(short id, short item);
const MenuPickType *MenuCmdPick(MenuCommandType cmd);
MenuHandle MenuCmdHandle(MenuCommandType cmd);
short MenuCmdItem(MenuCommandType cmd);
short MenuCmdID(MenuCommandType cmd);
void MenuCmdEnable(MenuCommandType cmd);
void MenuCmdDisable(MenuCommandType cmd);
void MenuCmdCheck(MenuCommandType cmd, Boolean check);

/* searching a menu */
short MenuFindItem(MenuHandle menu, const CStr255 title);

/* setting check marks */
void MenuUncheck(MenuHandle menu);

/* accessing menus and the menu list */
MenuHandle MenuHandleGet(short id);
short MenuListCount(void);
MenuHandle MenuListGet(short index);
void MenuBounds(MenuHandle menu, Rect *bounds);

/* enabling and disabling menus and adjusting menus */
void MenuEnable(MenuHandle menu, short item, Boolean enable);
Boolean MenuEnabled(MenuHandle menu, short item);
long MenuBarState(void);
void MenuBarEnable(long flags);
void MenuOutlineSizes(MenuHandle menu, short family, Boolean outlined);

/* creating and setting up menus */
void MenuAppend(short id);
void MenuBarGet(short id);
void MenuAdjust(void);

