#pragma once

/* Standard resources used by the libraries. Resource IDs 128 through 511 are
	reserved for the libraries. Every definition of a resource ID is preceded
	with the letters "RL", which stands for "Resource Library". This is followed
	by the type of the resource, or, in the case of 'STR#' resources, only
	by the letter "S". Menus are preceded by the letter "M", dialogs by the 
	letter "D". */

/* 'STR#' resources */
enum {
	RLS_ERR = 128,				/* error strings */
	RLS_ALERT,					/* alert strings */
	RLS_FILE,					/* names of files and folders */
	RLS_SF,						/* prompts for standard file put dialogs */
	RLS_BUSY,					/* progress dialog strings */
	RLS_BUTTON,					/* alert and dialog buttons */
	RLS_UNDO,					/* undo strings for edit menu */
	__RLS_UNUSED__,			/* unused resource */
	RLS_PRINTING,				/* printing related strings */
	RLS_ERRFMT,					/* error format strings */
	RLS_HELP,					/* help topics */
	RLS_FINDER,					/* finder messages */
	RLS_UNITS_SINGULAR,		/* units of measure (singular) */
	RLS_UNITS_PLURAL,			/* units of measure (plural) */
	RLS_LAST
};

/* error format strings */
enum {
	RLS_ERRFMT_ACTION = 1,
	RLS_ERRFMT_OPERATION,
	RLS_ERRFMT_OPERATION_ON,
	RLS_ERRFMT_OBJECT,
	RLS_ERRFMT_EXPLANATION,
	RLS_ERRFMT_OSERR,
	RLS_ERRFMT_LAST
};

/* error strings */
enum {
	RLS_ERR_OPEN = 1,
	RLS_ERR_CLOSE,
	RLS_ERR_READ,
	RLS_ERR_WRITE,
	RLS_ERR_CREATE,
	RLS_ERR_DELETE,
	RLS_ERR_PRINT,
	RLS_ERR_PAGE_SETUP,
	RLS_ERR_FIND,
	RLS_ERR_INSERT,
	RLS_ERR_ADD,
	RLS_ERR_REMOVE,
	RLS_ERR_INSTALL,
	RLS_ERR_UPDATE,
	RLS_ERR_MODIFY,
	RLS_ERR_REPLACE,
	RLS_ERR_SCAN,
	RLS_ERR_LAST
};

/* alert strings */
enum {
	RLS_ALERT_SYSTEM = 1,		/* application requires newer system */
	RLS_ALERT_SYSTEM_FEATURE,	/* feature requires newer system */
	RLS_ALERT_CLOSING,			/* save changes before closing? */
	RLS_ALERT_QUTTING,			/* save changes before quitting? */
	RLS_ALERT_REVERT,				/* really revert file? */
	RLS_ALERT_DAMAGED,			/* damaged application */
	RLS_ALERT_MEMORY_CLOSING,	/* close because memory is low */
	RLS_ALERT_MEMORY_LOW,		/* memory is low */
	RLS_ALERT_MEMORY_VERY_LOW, /* memory is very low */
	RLS_ALERT_MEMORY_CRITICAL, /* memory is critically low */
	RLS_ALERT_TRUNCATED,			/* document was truncated */
	RLS_ALERT_LAST
};

/* files used by application */
enum {
	RLS_FILE_PREFERENCES = 1,	/* preferences file */
	RLS_FILE_UNTITLED,			/* untitled document */
	RLS_FILE_APPLICATION,		/* name of application */
	RLS_FILE_UNTITLED_FOLDER,	/* untitled folder */
	RLS_FILE_PREFERENCES_FOLDER,/* preferences folder (for system 6.0) */
	RLS_FILE_DEBUG,				/* debug file/window */
	RLS_FILE_LAST
};

/* standard put file prompts */
enum {
	RLS_SF_SAVE = 1,				/* save as: */
	RLS_SF_FOLDER,					/* destination folder: */
	RLS_SF_SELECT_FOLDER,		/* select folder: */
	RLS_SF_SELECT_FILE,			/* select file: */
	RLS_SF_SELECT_FOLDERS,		/* select folders: */
	RLS_SF_SELECT_FILES,			/* select files: */
	RLS_SF_SELECT_FILE_OR_FOLDER, /* select file or folder: */
	RLS_SF_SELECT_FILES_AND_FOLDERS, /* select files and folders: */
	RLS_SF_LAST
};

/* periodic event loop strings */
enum {
	RLS_BUSY_READ = 1,		/* reading file */
	RLS_BUSY_WRITE,			/* writing file */
	RLS_BUSY_COPYING,			/* copying file */
	RLS_BUSY_CONCATENATING,	/* concatenating file */
	RLS_BUSY_SCANNING,		/* scanning file */
	RLS_BUSY_COUNTING_FILES, /* counting files */
	RLS_BUSY_LAST
};

/* alert and dialog button strings */
enum {
	RLS_BUTTON_YES = 1,
	RLS_BUTTON_NO,
	RLS_BUTTON_CANCEL,
	RLS_BUTTON_STOP,
	RLS_BUTTON_PAUSE,
	RLS_BUTTON_CONTINUE,
	RLS_BUTTON_ADD,
	RLS_BUTTON_DELETE,
	RLS_BUTTON_MODIFY,
	RLS_BUTTON_CHANGE,
	RLS_BUTTON_REPLACE,
	RLS_BUTTON_QUIT,
	RLS_BUTTON_SET,
	RLS_BUTTON_REVERT,
	RLS_BUTTON_SELECT,
	RLS_BUTTON_LAST
};

/* printing strings */
enum {
	RLS_PRINTING_PRINTING = 1,	/* Printing */
	RLS_PRINTING_SPOOLING,		/* Spooling */
	RLS_PRINTING_STOPPING,		/* Stopping print job */
	RLS_PRINTING_LAST
};

/* finder messages */
enum {
	RLS_FINDER_PREFS = 1,		/* default message for preferences file */
	RLS_FINDER_LAST
};

/* units of measure */
enum {
	RLS_UNITS_MILLIMETERS = 1,
	RLS_UNITS_CENTIMETERS,
	RLS_UNITS_INCHES,
	RLS_UNITS_POINTS,
	RLS_UNITS_LAST
};

/* pictures */
enum {
	RLPICT_ABOUT = 128,			/* picture for about dialog */
	RLPICT_LAST
};

/* window definitions */
enum {
	RLWDEF_SYSTEM = 0,			/* standard WDEF */
	RLWDEF_MOVABLE_MODAL=128,	/* movable-modal WDEF for pre-7.0 systems */
	RLWDEF_FLOAT = 129,			/* floating windoid */
	RLWDEF_LAST
};

/* windows */
enum {
	RLW_CLIPBOARD = 128,			/* clipboard window */
	RLW_DOCUMENT,					/* document window */
	RLW_FLOAT_DRAG_TOP,			/* floating window, drag bar on top */
	RLW_FLOAT_DRAG_LEFT,			/* floating window, drag bar on left */
	RLW_FLOAT_MENU = RLW_FLOAT_DRAG_TOP,	/* floating menu window */
	RLW_TOOL_BAR = RLW_FLOAT_DRAG_LEFT,		/* tool bar */
	RLW_LAST
};

/* dialogs */
enum {
	RLD_ABOUT = 128,				/* about dialog */
	RLD_BUSY,						/* doing some lengthy operation */
	RLD_DEBUG_MEMORY,				/* memory window */
	RLD_HELP,						/* help dialog */
	RLD_FOLDER,						/* folder selection dialog */
	RLD_MULTIPLE,					/* multiple file selection dialog */
	RLD_TXSIZE,						/* other size */
	RLD_TXWRAP,						/* word wrap */
	RLD_PREFERENCES,				/* preferences */
	RLD_LAST
};

/* alerts */
enum {
	RLA_OK = 256,					/* alert with an "OK" button */
	RLA_OK_CANCEL,					/* alert with "OK" and "Cancel" buttons */
	RLA_CANCEL_OK,					/* cancel button is the default item */
	RLA_SAVE,						/* save changes before... */
	RLA_LAST
};

/* dialog item templates */
enum {
	RLDITL_ABOUT = 128,
	RLDITL_BUSY,
	RLDITL_PRINTING,
	RLDITL_ALERT_OK = 256,
	RLDITL_ALERT_OK_CANCEL,
	RLDITL_ALERT_SAVE,
	RLDITL_LAST
};

/* 'ICN#' resources */
enum {
	RLICN_APPLICATION = 128,	/* application's icon */
	RLICN_DOCUMENT,				/* document file */
	RLICN_STATIONARY,				/* stationary file */
	RLICN_EDITION,					/* edition file */
	RLICN_PREFERENCES,			/* preferences file */
	RLICN_LAST
};

/* small icons */
enum {
	RLSICN_APPLICATION = 128,
	RLSICN_DOCUMENT,
	RLSICN_STATIONARY,	
	RLSICN_EDITION,
	RLSICN_PREFERENCES,
	RLSICN_GROW,
	RLSICN_LAST
};

/* file references */
enum {
	RLFREF_APPLICATION = 128,
	RLFREF_DOCUMENT,
	RLFREF_STATIONARY,
	RLFREF_EDITION,
	RLFREF_PREFERENCES,
	RLFREF_LAST
};

/* bundles */
enum {
	RL_BNDL_APPLICATION = 128,
	RL_BNDL_LAST
};

/* control definitions */
enum {
	RLCDEF_THUMBWHEEL = 128,		/* one of JohnC's controls */
	RLCDEF_LAST
};

/* cursors */
#define RLACUR_BUSY			(128)	/* animated busy cursors */
#define RLCURS_BUSY			(128)	/* first busy cursor */
#define RLCURS_BUSY_COUNT	(8)	/* number of busy cursors */

/* menu bars */
#define RLMBAR					(128)	/* application's menu bar */

/* menus */
enum {
	RLM_APPLE = 128,
	RLM_FILE,
	RLM_EDIT,
	RLM_FONT,
	RLM_SIZE,
	RLM_STYLE,
	RLM_WINDOWS,
	RLM_TEXT,
	RLM_DEBUG,
	RLM_UNITS_POPUP,
	RLM_SIZE_POPUP,
	RLM_FONT_POPUP,
	RLM_JUST,
	RLM_JUST_POPUP,
	RLM_LAST
};

/* size resources */
enum {
	RLSIZE_DEFAULT = -1,
	RLSIZE_USER,
	RLSIZE_LAST
};

/* version resources */
enum {
	RLVERS_APPLICATION = 1,
	RLVERS_GROUP,
	RLVERS_LAST
};

/* application settings */
enum {
	RLAPP_SETTINGS = 128,
	RLAPP_LAST
};

/* notification settings */
enum {
	RLNMOP_BACKGROUND = 128,
	RLNMOP_LAST
};
