/* Copyright (c) 1992 Ari I. Halberstadt */

/* definitions private to the sort library */

#ifndef _H_sort_private
#define _H_sort_private

/* get the i'th item from the array (base and size are local variables) */
#define get(i) ((void*)((char*)base + size * (i)))

/* return predecessor and succesor of pointer p (size is a local variable) */
#define pred(p) ((void*)((char*)(p) - size))
#define succ(p) ((void*)((char*)(p) + size))

/* The execution time of the sorts might be significantly improved by
   replacing calls to the comparison, copying, and swap functions
   with in-line code or with code optimized for the specific
   data. The greatest improvement will be noticed if you replace
   the comparison function with in-line code. For instance,
   when sorting integers try using an expression such as
     (*(int*)(a) - *(int*)(b))
   Be careful that any macro you use does not evaluate any
   of its parameters more than once. Also, the COPY macro
   should be compatible with memcpy. */
	
#ifndef compar
  #define compar(a, b)	compar(a, b)
#endif

#define COPY(a, b, n)	memcpy(a, b, n)

/* Swap the first N bytes of A and B. Using a macro is usually
   faster than calling a function. */
#define SWAP(a, b, n)\
{\
  register char *_a = a, *_b = b, _tmp;\
  register size_t _n = n;\
  \
  while (_n-- > 0) {\
    _tmp = *_a;\
    *_a++ = *_b;\
    *_b++ = _tmp;\
  }\
}

/* private insertion sort for qksort */
void _insort(void *base, size_t nmemb, register size_t size,
  register int (*compar)(const void *, const void *), size_t n);
  
#endif
