/* event table functions, called from event library in response to
	events
	
	93/10/18 aih - created */
	
#include "EventLib.h"
#include "TextScrollLib.h"

static EventTableType gEventTable;

static Boolean menu(EventObjectType object, const MenuPickType *pick)
{
	TxScrlMenu(object, pick);
}

static void adjustmenu(EventObjectType object)
{
	TxScrlAdjustMenu(object);
}

static TicksType adjustsleep(EventObjectType object)
{
	return TxScrlAdjustSleep(object);
}

static void idle(EventObjectType object)
{
	TxIdle(TxScrlText(object));
}

static Boolean within(EventObjectType object, Point where)
{
	return TxScrlWithin(object, where);
}

static Boolean mousedown(EventObjectType object, EventRecord *event)
{
	FocusSet(object);
	return TxScrlMouseDown(object, event);
}

static void keydown(EventObjectType object, EventRecord *event)
{
	TxScrlKeyDown(object, event);
}

static void selectall(EventObjectType object)
{
	TxSelectAll(TxScrlText(object));
}

static void focus(EventObjectType object, Boolean focus)
{
	TxFocus(TxScrlText(object), focus);
}

static void prefilter(EventObjectType object, EventRecord *event)
{
	TxScrlFilterPre(object, event);
}

static void ResizeTask(TaskHandle task, void *data)
{
	TextScrollHandle scrl = data;

	require((**scrl).resizeTask == task);
	TxScrlResized(scrl);
	EventPostTaskDelete(task);
	(**scrl).resizeTask = NULL;
}

static void resize(EventObjectType object, short dh, short dv)
{
	TextScrollHandle scrl = object;
	
	if (! (**scrl).resizeTask) {
		TaskHandle task = EventPostTaskInsert(ResizeTask, scrl);
		(**scrl).resizeTask = task;
	}
}

const /* EventTableType */ void *TxScrlEventTable(void)
{
	return(&gEventTable);
}

void TxScrlEventTableRegister(void)
{	
	gEventTable.focusObject.idle = idle;
	gEventTable.focusObject.keydown = keydown;
	gEventTable.focusObject.menu = menu;
	gEventTable.focusObject.adjustmenu = adjustmenu;
	gEventTable.focusWindow.adjustsleep = adjustsleep;
	gEventTable.focusWindow.within = within;
	gEventTable.focusWindow.mousedown = mousedown;
	gEventTable.focusWindow.selectall = selectall;
	gEventTable.focusWindow.focus = focus;
	gEventTable.focusWindow.prefilter = prefilter;
	gEventTable.window.resize = resize;
	EventTableRegister(&gEventTable);
}
