#pragma once

#include "DrawLib.h"
#include "MenuLib.h"
#include "ScrollBarLib.h"
#include "TimeLib.h"
#include "TaskLib.h"
#include "TextLib.h"
#include "TextUndoLib.h"

#define TXSCRL_BUFSZ	(16)				/* size of key input buffer */

typedef struct TextScrollType {
	char					buf[TXSCRL_BUFSZ];/* key buffer */
	char					bufsz;			/* number of keys in buffer */
	Boolean				buffered:1;		/* true if should use key buffer */
	Boolean				dirty:1;			/* true if modified text */
	TextHandle			text;				/* the text record */
	TextUndoHandle		undo;				/* undo data */
	ScrollBarHandle 	hsbar;			/* horizontal scroll bar */
	ScrollBarHandle	vsbar;			/* vertical scroll bar */
	TaskHandle			resizeTask;		/* task for resizing text */
} TextScrollType, *TextScrollPtr, **TextScrollHandle;

Boolean TxScrlValid(TextScrollHandle scrl);

WindowPtr TxScrlWindow(TextScrollHandle scrl);
TextHandle TxScrlText(TextScrollHandle scrl);
FrameHandle TxScrlFrame(TextScrollHandle scrl);
Boolean TxScrlDirty(TextScrollHandle scrl);
void TxScrlDirtySet(TextScrollHandle scrl, Boolean dirty);

void TxScrlChanged(TextScrollHandle scrl);
void TxScrlShowSel(TextScrollHandle scrl);
void TxScrlScroll(TextScrollHandle scrl, TextIntType dh, TextIntType dv);

void TxScrlResized(TextScrollHandle scrl);
void TxScrlKey(TextScrollHandle scrl, char key);
void TxScrlKeyDown(TextScrollHandle scrl, EventRecord *event);
Boolean TxScrlWithin(TextScrollHandle scrl, Point where);
Boolean TxScrlMouseDown(TextScrollHandle scrl, EventRecord *event);
Boolean TxScrlMenu(TextScrollHandle scrl, const MenuPickType *pick);
void TxScrlAdjustMenu(TextScrollHandle scrl);
TicksType TxScrlAdjustSleep(TextScrollHandle scrl);

void TxScrlUndo(TextScrollHandle scrl);
void TxScrlCut(TextScrollHandle scrl);
void TxScrlCopy(TextScrollHandle scrl);
void TxScrlPaste(TextScrollHandle scrl);
void TxScrlClear(TextScrollHandle scrl);
void TxScrlStyleSet(TextScrollHandle scrl, short mode, TextStyle *style);

void TxScrlFlushBuffer(TextScrollHandle scrl);
void TxScrlBuffer(TextScrollHandle scrl, char key);
void TxScrlFilterPre(TextScrollHandle scrl, EventRecord *event);

TextScrollHandle TxScrlBegin(WindowPtr window, const Rect *bounds,
	Boolean vertical, Boolean horizontal, Boolean undoable, Boolean buffered,
	TextKindType textKind, const TextState *textState);
void TxScrlEnd(TextScrollHandle scrl);

const /* EventTableType */ void *TxScrlEventTable(void);
void TxScrlEventTableRegister(void);
