/* Display a dialog for setting a custom font size.
	93/11/09 aih
	- modified to use TextHandle instead of TextScrollHandle for sample text
	
	93/03/19 Ari Halberstadt (AIH)
	- Split out of TextDocumentEventLib.c */
	
#include <stdio.h>
#include <string.h>
#include <Script.h>
#include "DialogLib.h"
#include "DialogModalLib.h"
#include "DrawLib.h"
#include "EventLib.h"
#include "KeyLib.h"
#include "MemoryLib.h"
#include "RectangleLib.h"
#include "ResourceConstantsLib.h"
#include "TextSizeDialogLib.h"
#include "TextIOLib.h"

/* items in the dialog */
enum {
	iSizeText = 3,
	iSampleText,
	iUpDownButton
};

/* return size */
static short GetSize(DialogPtr dlg)
{
	short size = DlgNum(dlg, iSizeText);
	
	if (size < TX_MIN_FONT)
		size = TX_MIN_FONT;
	else if (size > TX_MAX_FONT)
		size = TX_MAX_FONT;
	ensure(TX_MIN_FONT <= size && size <= TX_MAX_FONT);
	return(size);
}

/* set size item */
static void SetSize(DialogPtr dlg, short size)
{
	if (size < TX_MIN_FONT)
		size = TX_MIN_FONT;
	else if (size > TX_MAX_FONT)
		size = TX_MAX_FONT;
	DlgNumSet(dlg, iSizeText, size);
}

/* set the sample text to the size specified in the dialog */
static void SetTextSize(TextHandle text, short size)
{
	TextStyle style;
	
	if (size != TxSize(text)) {
		style.tsSize = size;
		TxSelectAll(text);
		TxStyleSet(text, doSize, &style);
	}
	ensure(TxSize(text) == size);
}

/* increase or decrease the size */
static pascal void track(ControlHandle control, short part)
{
	DialogPtr dlg = CtlWindow(control);
	
	if (part == inUpButton || part == inDownButton)
		SetSize(dlg, (part == inUpButton) ? GetSize(dlg) + 1 : GetSize(dlg) - 1);
}

/* handle a click in the up/down control */
static Boolean filter(DialogPtr dlg, EventRecord *event, short *item,
	void *data)
{
	TextHandle 		text = NULL;	/* sample text */
	TextHandle		size = NULL;	/* size item */
	ControlHandle	control = NULL;/* the thumb wheel control */
	unsigned char	key = 0;			/* key pressed */
	short				part = 0;		/* part of window clicked */
	Point				where;			/* local coordinates of mouse click */
	Boolean			stop = false;	/* true if should exit modal dialog loop */
	
	text = WinRegisteredID(dlg, iSampleText);
	size = WinRegisteredID(dlg, iSizeText);
	switch (event->what) {
	case nullEvent:
		SetTextSize(text, GetSize(dlg));
		break;
	case mouseDown:
		/* handle click in the up/down button */
		where = event->where;
		GlobalToPort(&where, dlg);
		part = FindControl(where, dlg, &control);
		if (part && control == DlgCtl(dlg, iUpDownButton)) {
			TxActivate(size, false);
			TrackControl(control, where, (ProcPtr) track);
			DlgTextSelectAll(dlg, iSizeText);
			TxActivate(size, true);
			SetTextSize(text, GetSize(dlg));
			event->what = nullEvent;
			stop = true;
		}
		break;
	}
	return(stop);
}

/* Display the "Other Size" dialog for setting a different font size
	than is provided for in the "Size" menu. Returns the indicated font size, or
	0 if the dialog is canceled. The 'mode' and 'style' parameter specify
	the text style for the sample text. You can use the 'mode' and 'style'
	parameters to get the style information for the current selection,
	to which this size dialog will apply. */
short TxSizeDialog(short mode, TextStyle *style)
{
	volatile DialogPtr dlg = NULL;
	TextHandle text = NULL;
	short	item = 0;
	short	result = 0;
	
	TRY {
		dlg = DlgBegin(RLD_TXSIZE);
		text = WinRegisteredID(dlg, iSampleText);
		TxWrapSet(text, true);
		TxCalculate(text);
		TxSelectAll(text);
		TxStyleSet(text, mode, style);
		TxHookKeySet(WinRegisteredID(dlg, iSizeText), TxHookKeyUnsignedInteger);
		DlgModalFilterSet(dlg, filter, NULL);
		DlgNumSet(dlg, iSizeText, style->tsSize);
		DlgTextSelectAll(dlg, iSizeText);
		WinShow(dlg);
		do {
			item = DlgModalRun(dlg);
		} while (item != ok && item != cancel);
		if (item == ok)
			result = GetSize(dlg);
	} CLEANUP {
		DlgEnd(dlg);
	} ENDTRY;
	ensure(result == 0 || (TX_MIN_FONT <= result && result <= TX_MAX_FONT));
	return(result);
}
