#pragma once

#include "TextLib.h"

/* Undo/redo constants. Can be used as indexes to a 'STR#' resource
	to set the "Undo" menu item. */
typedef enum {
	TXUNDO_NULL,
	TXUNDO_CUT,
	TXUNDO_COPY,
	TXUNDO_PASTE,
	TXUNDO_CLEAR,
	TXUNDO_STYLE,
	TXUNDO_TYPING,
	TXREDO_TYPING,
	TXREDO_STYLE,
	TXREDO_CUT,
	TXREDO_COPY,
	TXREDO_PASTE,
	TXREDO_CLEAR,
	TXUNDO_LAST
} TxUndoStatusType;

/* undo data */
typedef struct TextUndoStruct {
	TxUndoStatusType	status;		/* determines what must be done at next undo command */
	TextHandle			text;			/* the text record */
	StScrpHandle		svstyle;		/* saved style scrap */
	Handle				svtext;		/* saved text */
	Boolean				typingRun;	/* flag that we're in a typing run */
	Boolean				styleSaved;	/* true if we've already saved the style info */
	TextIntType			undoStart;	/* start of text to which buffer applies */
	TextIntType			undoEnd;		/* end of text to which buffer applies */
} TextUndoType, *TextUndoPtr, **TextUndoHandle;

Boolean TxUndoValid(TextUndoHandle undo);
TxUndoStatusType TxUndoStatus(TextUndoHandle undo);
void TxUndoReset(TextUndoHandle undo);
void TxUndo(TextUndoHandle undo);
void TxUndoCut(TextUndoHandle undo);
void TxUndoCopy(TextUndoHandle undo);
void TxUndoPaste(TextUndoHandle undo);
void TxUndoClear(TextUndoHandle undo);
void TxUndoStyleSet(TextUndoHandle undo, short mode, TextStyle *style);
void TxUndoKey(TextUndoHandle undo, char key);
void TxUndoClick(TextUndoHandle undo);
void TxUndoAdjustMenu(TextUndoHandle undo);
TextUndoHandle TxUndoBegin(TextHandle text);
void TxUndoEnd(TextUndoHandle undo);
